@@ -51,6 +51,18 @@ class Quote(dict):
     def Time(self):
         return super().get('Time')
 
+    def Pause(self):
+        return super().get('Pause')
+
+    def TradeType(self):
+        return super().get('TradeType')
+
+    def BestBuy(self):
+        return super().get('BestBuy')
+
+    def BestSell(self):
+        return super().get('BestSell')
+
     # 'AskPrice': [14.4, 14.45, 14.5, 14.55, 14.6], 'AskVolume': [2239, 370, 428, 88, 316]
     # {14.4: 2239, 14.45: 370, 14.5: 428, 14.55: 88, 14.6: 316}
     def zipAsk(self):
@@ -109,6 +121,17 @@ class Market(dict):
         value = super().get('Volume')
         return value[0] if isinstance(value, list) else value
 
+    def Pause(self):
+        return super().get('Pause')
+
+    def TradeType(self):
+        return super().get('TradeType')
+
+    def BestBuy(self):
+        return super().get('BestBuy')
+
+    def BestSell(self):
+        return super().get('BestSell')
 
 
 class SJ_wrapper:
@@ -194,7 +217,6 @@ def converter_SJ_ticks_to_MC():
                         fp = tx
 
 
-
 if __name__ == '__main__':
 
     if True:
@@ -202,4 +224,3 @@ if __name__ == '__main__':
 
     if False:
         converter_SJ_ticks_to_MC()
-
