@@ -2,6 +2,7 @@
 import threading
 from line_notify import LineNotify
 import queue
+from loguru import logger
 
 
 
@@ -35,7 +36,11 @@ class tLineNotify(threading.Thread):
             else:
                 if message is None:
                     break
-                self.line_notify.send(message=message, image_path=image_path, sticker_id=sticker_id, package_id=package_id)
+                try:
+                    self.line_notify.send(message=message, image_path=image_path, sticker_id=sticker_id, package_id=package_id)
+                except Exception as e:
+                    logger.error(f'Somehow line notify error: {message}')
+                    logger.error(e)
 
     def stop(self):
         self.queue.put((None, None, None, None))
