@@ -4,6 +4,9 @@ import queue
 import os
 from playsound import playsound
 from loguru import logger
+import datetime
+from collections import defaultdict
+
 
 if os.name == 'nt':
     import winsound
@@ -15,18 +18,29 @@ class tplaysound(threading.Thread):
     def __init__(self):
         threading.Thread.__init__(self)
 
+        self.time_block = 2
+
         self.queue = queue.Queue()
 
         self.file_sound_alert = f'{_MYPYLIB_ROOT}/../data/alert.wav'
 
         self.start()
 
+        self.dict_filename_to_datetime = defaultdict(datetime.datetime.now)
+
+    def block_or_not(self, filename):
+        return (datetime.datetime.now() - self.dict_filename_to_datetime[filename]).seconds < self.time_block
+
     def play(self, filename=None):
         self.play_file(filename=filename)
 
     def play_file(self, filename=None):
         if filename is None:
             filename = self.file_sound_alert
+
+        if self.block_or_not(filename):
+            return
+
         command = ('play', filename)
         self.queue.put(command)
         # print(f'send command {command}')
