@@ -116,11 +116,11 @@ class Tredis_subscribe(threading.Thread):
         self.sub.subscribe(self.channel)
         for message in self.sub.listen():
             if message:
-                logger.info(f'REDIS got message: [{message}]')
+                # logger.info(f'REDIS got message: [{message}]')
                 try:
                     channel = message['channel']
                     data = message['data']
-                    logger.info(f'redis_working_thread got msg: {data}')
+                    # logger.info(f'redis_working_thread got msg: {data}')
 
                     if isinstance(data, str) and data.startswith(self.str_thread_exit_magic):
                         if data[len(self.str_thread_exit_magic) + 1:] == str(self):
@@ -129,7 +129,7 @@ class Tredis_subscribe(threading.Thread):
                     else:
                         function_send = getattr(self.redis_msg_sender, 'redis_msg_sender', None)
                         if function_send is not None and callable(function_send):
-                            logger.info(f'function_send: {data}')
+                            # logger.info(f'function_send: {data}')
                             function_send(channel, data)
                 except Exception as e:
                     traceback.print_exc()
